Update your application's privacy policy to explicitly state that browsing activity is collected. Clearly describe the types of browsing data collected, the purposes for its collection, how the data is used, stored, its retention period, and any use of cookies or similar tracking technologies. Ensure users are provided with transparent information and appropriate consent mechanisms.